@@ -26,6 +26,8 @@ int mk_wcswidth(const wchar_t *pwcs, size_t n);
 int mk_wcwidth_cjk(wchar_t ucs);
 int mk_wcswidth_cjk(const wchar_t *pwcs, size_t n);
 #if defined (_WIN32) && !defined(__CYGWIN__)
+/* Watccom C, MS-VS, and MinGW don't have wc(s)width().
+   MinGW-w64 has wc(s)width(). */
 int wcwidth(wchar_t ucs);
 int wcswidth(const wchar_t *pwcs, size_t n);
 #endif
